﻿#Region " Import(s) "

Imports System.Globalization
Imports System.IO

#End Region

<Assembly: CLSCompliant(True)> 

Public Class Main

#Region " Fields "

    Private mWADFileInfoList As New SortableListCollection(Of WADFileInfo)

#End Region

#Region " Events "

    Private Sub Main_DragDrop(ByVal sender As Object, ByVal e As System.Windows.Forms.DragEventArgs) Handles Me.DragDrop
        Try
            Cursor = Cursors.WaitCursor

            If e.Data.GetDataPresent(DataFormats.FileDrop) Then
                mWADFileInfoList.Clear()

                Dim itemsDropped As String() = DirectCast(e.Data.GetData(DataFormats.FileDrop), String())

                For Each currentItem As String In itemsDropped

                    ' Check if this is a file or a folder
                    If My.Computer.FileSystem.DirectoryExists(currentItem) Then
                        Dim files As FileInfo() = GetFiles(currentItem, "*.WAD")

                        For Each file As FileInfo In files
                            Dim infoWAD As New InfoWAD(My.Computer.FileSystem.CombinePath(currentItem, file.Name))

                            mWADFileInfoList.Add(New WADFileInfo(infoWAD.TitleId, infoWAD.Region, infoWAD.Blocs, infoWAD.Folder, infoWAD.DataFiles, file.Name))
                        Next
                    Else
                        If My.Computer.FileSystem.GetFileInfo(currentItem).Extension.ToUpper(CultureInfo.InvariantCulture) = ".WAD" Then
                            Dim infoWAD As New InfoWAD(currentItem)

                            mWADFileInfoList.Add(New WADFileInfo(infoWAD.TitleId, infoWAD.Region, infoWAD.Blocs, infoWAD.Folder, infoWAD.DataFiles, My.Computer.FileSystem.GetName(currentItem)))
                        End If
                    End If
                Next

                ' Set the DataSource to display the ArrayList content then refresh the DataGrid
                With uxDataGridView
                    .DataSource = Nothing
                    .DataSource = mWADFileInfoList

                    If mWADFileInfoList.Count <> 0 Then
                        .Columns(0).HeaderText = "Title ID"
                        .Columns(1).HeaderText = "Region"
                        .Columns(1).ReadOnly = True
                        .Columns(2).HeaderText = "Blocks"
                        .Columns(2).ReadOnly = True
                        .Columns(3).HeaderText = "Folder"
                        .Columns(3).ReadOnly = True
                        .Columns(4).HeaderText = "Data Files"
                        .Columns(4).ReadOnly = True
                        .Columns(5).HeaderText = "Filename"
                        .Columns(5).ReadOnly = True

                        Call AdjustDataGridViewColWidth()
                    End If

                    .Refresh()

                    labelWADs.Text = String.Format(CultureInfo.InvariantCulture, "{0} WAD{1}", .RowCount, If(.RowCount < 2, String.Empty, "s"))
                End With
            End If

        Catch ex As Exception
            With uxDataGridView
                .DataSource = Nothing
                .Refresh()
            End With

            mWADFileInfoList.Clear()

        Finally
            Cursor = Cursors.Default
        End Try
    End Sub

    Private Sub Main_DragEnter(ByVal sender As Object, ByVal e As System.Windows.Forms.DragEventArgs) Handles Me.DragEnter
        If e.Data.GetDataPresent(DataFormats.FileDrop) Then
            e.Effect = DragDropEffects.Copy
        Else
            e.Effect = DragDropEffects.None
        End If
    End Sub

    Private Sub Main_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        Text = String.Format(CultureInfo.InvariantCulture, "{0} v{1}.{2}.{3}", My.Application.Info.Title, My.Application.Info.Version.Major, My.Application.Info.Version.Minor, My.Application.Info.Version.Build)

        AllowDrop = True
        KeyPreview = True

        Call PrepareDataGridView()
    End Sub

    Private Sub Main_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyEventArgs) Handles Me.KeyDown
        If e.KeyCode = Keys.Escape Then
            Close()
        End If
    End Sub

    Private Sub Main_SizeChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.SizeChanged
        Call AdjustDataGridViewColWidth()
    End Sub

#End Region

#Region " Private Methods "

    Private Sub PrepareDataGridView()
        With uxDataGridView
            .AllowUserToAddRows = False
            .AllowUserToDeleteRows = False
            .AllowUserToOrderColumns = True
            .AllowUserToResizeRows = False
            .AutoGenerateColumns = True

            .AutoSizeColumnsMode = DataGridViewAutoSizeColumnsMode.None
            .ColumnHeadersDefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleCenter
            .ColumnHeadersHeightSizeMode = System.Windows.Forms.DataGridViewColumnHeadersHeightSizeMode.AutoSize

            .MultiSelect = False
            .ReadOnly = False
            .RowHeadersVisible = False
            .SelectionMode = System.Windows.Forms.DataGridViewSelectionMode.FullRowSelect

            .AlternatingRowsDefaultCellStyle.BackColor = Color.FromArgb(255, 255, 217)
            .RowsDefaultCellStyle.BackColor = Color.FromArgb(217, 234, 255)
        End With
    End Sub

    Private Function GetFiles(ByVal path As String, ByVal fileExtension As String) As IO.FileInfo()
        Try
            Return New DirectoryInfo(path).GetFiles(fileExtension)

        Catch ex As DirectoryNotFoundException
            Return Nothing

        Catch ex As Exception
            Return Nothing
        End Try
    End Function

    ' Adjusting DataGridView Column Width
    Private Sub AdjustDataGridViewColWidth()
        With uxDataGridView
            If uxDataGridView.RowCount <> 0 Then
                .Columns(0).Width = 50
                .Columns(1).Width = 70
                .Columns(2).Width = 50
                .Columns(3).Width = 120
                .Columns(4).Width = 50

                Dim offset As Integer

                If .DisplayedRowCount(True) <> .RowCount Then
                    offset = 20
                Else
                    offset = 3
                End If

                .Columns(5).Width = uxDataGridView.Width - (.Columns(0).Width + .Columns(1).Width + .Columns(2).Width + .Columns(3).Width + .Columns(4).Width) - offset
            End If
        End With
    End Sub

#End Region

End Class
